==> jc-1.4.0.tar.gz: soot/dava/internal/javaRep/DLengthExpr.h <==
// public class soot.dava.internal.javaRep.DLengthExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 308ea1159a55740b soot_dava_internal_javaRep_DLengthExpr
// @dep_class d3526440663c1839 soot_jimple_internal_AbstractLengthExpr
// @dep_class 2880d6831146619b soot_jimple_internal_AbstractUnopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractLengthExpr

#include "soot/jimple/internal/AbstractLengthExpr.h"

#ifndef _JC_soot_dava_internal_javaRep_DLengthExpr_H_
#define _JC_soot_dava_internal_javaRep_DLengthExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DLengthExpr$sub_refs	_jc_soot_dava_internal_javaRep_DLengthExpr$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DLengthExpr$sub_nonrefs	_jc_soot_dava_internal_javaRep_DLengthExpr$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DLengthExpr$refs	_jc_soot_dava_internal_javaRep_DLengthExpr$refs;
typedef struct _jc_soot_dava_internal_javaRep_DLengthExpr$nonrefs	_jc_soot_dava_internal_javaRep_DLengthExpr$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DLengthExpr$object	_jc_soot_dava_internal_javaRep_DLengthExpr$object;

typedef const struct _jc_soot_dava_internal_javaRep_DLengthExpr$vmethods	_jc_soot_dava_internal_javaRep_DLengthExpr$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DLengthExpr$vtable	_jc_soot_dava_internal_javaRep_DLengthExpr$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DLengthExpr$vtype	_jc_soot_dava_internal_javaRep_DLengthExpr$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DLengthExpr$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_dava_internal_javaRep_DLengthExpr$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DLengthExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DLengthExpr$object *);
extern jint _jc_soot_dava_internal_javaRep_DLengthExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_dava_internal_javaRep_DLengthExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DLengthExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DLengthExpr$object *);
extern void _jc_soot_dava_internal_javaRep_DLengthExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DLengthExpr$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DLengthExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DLengthExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_dava_internal_javaRep_DLengthExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DLengthExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DLengthExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DLengthExpr$object *);
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DLengthExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DLengthExpr$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DLengthExpr$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DLengthExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractUnopExpr$vmethods	soot_jimple_internal_AbstractUnopExpr;
	_jc_soot_jimple_internal_AbstractLengthExpr$vmethods	soot_jimple_internal_AbstractLengthExpr;
	_jc_soot_dava_internal_javaRep_DLengthExpr$vmethods	soot_dava_internal_javaRep_DLengthExpr;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DLengthExpr$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DLengthExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DLengthExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DLengthExpr$refs {
    _jc_soot_dava_internal_javaRep_DLengthExpr$sub_refs	soot_dava_internal_javaRep_DLengthExpr;
    _jc_soot_jimple_internal_AbstractLengthExpr$sub_refs	soot_jimple_internal_AbstractLengthExpr;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs	soot_jimple_internal_AbstractUnopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DLengthExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DLengthExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs	soot_jimple_internal_AbstractUnopExpr;
    _jc_soot_jimple_internal_AbstractLengthExpr$sub_nonrefs	soot_jimple_internal_AbstractLengthExpr;
    _jc_soot_dava_internal_javaRep_DLengthExpr$sub_nonrefs	soot_dava_internal_javaRep_DLengthExpr;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DLengthExpr$object {
	_jc_soot_dava_internal_javaRep_DLengthExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DLengthExpr$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DLengthExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DLengthExpr$vtype _jc_soot_dava_internal_javaRep_DLengthExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DLengthExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DLengthExpr$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DLengthExpr_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/javaRep/DLengthExpr.h <==
// public class soot.dava.internal.javaRep.DLengthExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 308ea1159a55740b soot_dava_internal_javaRep_DLengthExpr
// @dep_class d3526440663c1839 soot_jimple_internal_AbstractLengthExpr
// @dep_class 2880d6831146619b soot_jimple_internal_AbstractUnopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractLengthExpr

#include "soot/jimple/internal/AbstractLengthExpr.h"

#ifndef _JC_soot_dava_internal_javaRep_DLengthExpr_H_
#define _JC_soot_dava_internal_javaRep_DLengthExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DLengthExpr$sub_refs	_jc_soot_dava_internal_javaRep_DLengthExpr$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DLengthExpr$sub_nonrefs	_jc_soot_dava_internal_javaRep_DLengthExpr$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DLengthExpr$refs	_jc_soot_dava_internal_javaRep_DLengthExpr$refs;
typedef struct _jc_soot_dava_internal_javaRep_DLengthExpr$nonrefs	_jc_soot_dava_internal_javaRep_DLengthExpr$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DLengthExpr$object	_jc_soot_dava_internal_javaRep_DLengthExpr$object;

typedef const struct _jc_soot_dava_internal_javaRep_DLengthExpr$vmethods	_jc_soot_dava_internal_javaRep_DLengthExpr$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DLengthExpr$vtable	_jc_soot_dava_internal_javaRep_DLengthExpr$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DLengthExpr$vtype	_jc_soot_dava_internal_javaRep_DLengthExpr$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DLengthExpr$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_dava_internal_javaRep_DLengthExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DLengthExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DLengthExpr$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_dava_internal_javaRep_DLengthExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_dava_internal_javaRep_DLengthExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DLengthExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DLengthExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_javaRep_DLengthExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DLengthExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DLengthExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DLengthExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_dava_internal_javaRep_DLengthExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DLengthExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DLengthExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DLengthExpr$object *) _JC_JCNI_ATTR;
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DLengthExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DLengthExpr$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DLengthExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DLengthExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractUnopExpr$vmethods	soot_jimple_internal_AbstractUnopExpr;
	_jc_soot_jimple_internal_AbstractLengthExpr$vmethods	soot_jimple_internal_AbstractLengthExpr;
	_jc_soot_dava_internal_javaRep_DLengthExpr$vmethods	soot_dava_internal_javaRep_DLengthExpr;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DLengthExpr$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DLengthExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DLengthExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DLengthExpr$refs {
    _jc_soot_dava_internal_javaRep_DLengthExpr$sub_refs	soot_dava_internal_javaRep_DLengthExpr;
    _jc_soot_jimple_internal_AbstractLengthExpr$sub_refs	soot_jimple_internal_AbstractLengthExpr;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs	soot_jimple_internal_AbstractUnopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DLengthExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DLengthExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs	soot_jimple_internal_AbstractUnopExpr;
    _jc_soot_jimple_internal_AbstractLengthExpr$sub_nonrefs	soot_jimple_internal_AbstractLengthExpr;
    _jc_soot_dava_internal_javaRep_DLengthExpr$sub_nonrefs	soot_dava_internal_javaRep_DLengthExpr;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DLengthExpr$object {
	_jc_soot_dava_internal_javaRep_DLengthExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DLengthExpr$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DLengthExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DLengthExpr$vtype _jc_soot_dava_internal_javaRep_DLengthExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DLengthExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DLengthExpr$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DLengthExpr_H_ */
